pub struct SeqresRecord {
pub ser_num: u32,
pub chain_id: char,
pub num_res: i16,
pub res_names: Vec<String>,
}Expand description
Represents a SEQRES record containing sequence information.
SEQRES records contain the amino acid or nucleic acid sequence of residues in each chain of the macromolecule. Multiple SEQRES records may be used for a single chain if the sequence is long.
Fields
ser_num: Serial number of the SEQRES record for the current chainchain_id: Chain identifiernum_res: Total number of residues in the chainres_names: List of residue names in this record
Example
use knuckles_parse::records::seqres::SeqresRecord;
let line = "SEQRES 1 A 147 THR SER ASN PHE ALA ASP GLY LYS ASP ALA ILE LEU GLU";
let seqres = SeqresRecord::from(line);
assert_eq!(seqres.chain_id, 'A');
assert_eq!(seqres.num_res, 147);Fields
ser_num: u32Serial number of this SEQRES record for the current chain
chain_id: charChain identifier
num_res: i16Total number of residues in the chain
res_names: Vec<String>List of residue names in this SEQRES record
Implementations